/* Japanese messages are separate to another file.             */
/* Because Japanese EUC-JP encoding is conflict with ISO-8859. */
/* By: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>         */

#ifndef __XLOCK_MSG_JP_H__
#define __XLOCK_MSG_JP_H__

#define JP_TIME_ELAPSED_MINUTES "åƤ %d ʬвᤷޤ                      \n"
#define JP_TIME_ELAPSED_HOURS   "åƤ %d  %02d ʬвᤷޤ              \n"
#define JP_BUTTON_MINUTES        "%d ʬ˥ȥܥ󤬽иޤ                   \n"
#define JP_BUTTON_HOURS          "%d  %02d ʬ˥ȥܥ󤬽иޤ         \n"
#define JP_AUTOLOGOUT_MINUTES    "ưȤޤ %d ʬ"
#define JP_AUTOLOGOUT_HOURS      "ưȤޤ %d  %02d ʬ"

#endif
